@@ -819,7 +819,7 @@ class CamsClient:
         uri = urljoin(asset_uri_prefix, asset_file_uri)
 
         files = {
-            "file": (output_key.split('/')[-1], value)
+            "file": (output_key.split('/')[-1], value, "application/octet-stream")
         }
 
         req = self.cpd_orchestration.prepare_request('PUT', uri, headers=headers, params=params, files=files)
